# GNN Enrich package

Please, see [documentation](https://cnrgh.gitlab.io/gnn-enrich/gnn-enrich) for more information.

## NEWS

### 1.1.0 - 2025-01-14

 * Remove interactions between genes inside the overlap region inside the
   correlation computing.
